<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package doo
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function doo_body_classes( $classes ) {
	// Adds a class of hfeed to non-doogular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	return $classes;
}
add_filter( 'body_class', 'doo_body_classes' );

/**
 * Add a pingback url auto-discovery header for doogularly identifiable articles.
 */
function doo_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'doo_pingback_header' );

function doo_sidebar_select() {	
	if(is_page()){
		$page_layout = get_theme_mod( 'page_layout', 'right_sidebar' );
		if($page_layout == "full"){
		
		}
		if($page_layout == "right_sidebar"){
			get_sidebar();
		}
	}else{
		$home_layout = get_theme_mod( 'home_layout', 'right_sidebar' );
		if($home_layout == "full"){
		
		}
		if($home_layout == "right_sidebar"){
			get_sidebar();
		}
	}
}

function doo_body_class( $classes ) {
	if(is_page()){
		$page_layout = get_theme_mod( 'page_layout', 'right_sidebar' );
		if($page_layout == "full"){
			$classes[] = 'no-sidebar-full-width';
		}
		if($page_layout == "right_sidebar"){
	
		}
	}else{
		$home_layout = get_theme_mod( 'home_layout', 'right_sidebar' );
		if($home_layout == "full"){
			$classes[] = 'no-sidebar-full-width';
		}
		if($home_layout == "right_sidebar"){
	
		}
	}
	return $classes;
}
add_filter( 'body_class', 'doo_body_class' );

function doo_color_theme() {
	$theme_color = esc_attr(get_theme_mod( 'theme_color', '#c51e3a' ));	
	if( $theme_color != '#c51e3a' ) {
		$custom_css = '';
		$custom_css .= 'blockquote {border-left: 4px solid '.$theme_color.';}';	
		$custom_css .= 'a {color: '.$theme_color.';}';
		$custom_css .= 'a:hover,a:focus,a:active {color: '.$theme_color.';}';
		$custom_css .= '.site-header{border-top: 3px solid '.$theme_color.';}';
		$custom_css .= '.site-title a:hover,.site-title a:focus,.site-title a:active{color:'.$theme_color.';}';
		$custom_css .= '.main-navigation div >ul >li >a:hover{color:'.$theme_color.';}';
		$custom_css .= '.main-navigation div >ul >li ul li a:hover{color:'.$theme_color.';}';
		$custom_css .= '.menu-toggle{color:'.$theme_color.';}';
		$custom_css .= '.entry-title a:hover{color:'.$theme_color.';}';	
		$custom_css .= '.sticky .entry-title,.sticky .entry-title a{color:'.$theme_color.';}';
		$custom_css .= '.widget a:hover{color:'.$theme_color.';}';
		$custom_css .= '.comment-form .logged-in-as a:hover{color:'.$theme_color.';}';
		$custom_css .= '.pagination .nav-links a:hover{background:'.$theme_color.';}';
		$custom_css .= '.pagination .nav-links .current{background:'.$theme_color.';}';
		$custom_css .= '.site-info a:hover{color:'.$theme_color.';}';
		$custom_css .= '#back_top {background:'.$theme_color.';}';
		echo '<style type="text/css">'.$custom_css.'</style>';
	}
}
add_action('wp_head', 'doo_color_theme');